# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import sort_direction_pb2 as sort__direction__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tasks_common.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x14sort_direction.proto\x1a\x11task_status.proto\"\x8d\x07\n\x07TaskRaw\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cowner_pod_id\x18\x03 \x01(\t\x12\x17\n\x0finitial_task_id\x18\x16 \x01(\t\x12\x17\n\x0fparent_task_ids\x18\x04 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x05 \x03(\t\x12\x1b\n\x13\x65xpected_output_ids\x18\x06 \x03(\t\x12\x14\n\x0cretry_of_ids\x18\x07 \x03(\t\x12;\n\x06status\x18\x08 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x16\n\x0estatus_message\x18\t \x01(\t\x12\x31\n\x07options\x18\n \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csubmitted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x18\x63reation_to_end_duration\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1aprocessing_to_end_duration\x18\x15 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x07pod_ttl\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06output\x18\x10 \x01(\x0b\x32).armonik.api.grpc.v1.tasks.TaskRaw.Output\x12\x14\n\x0cpod_hostname\x18\x11 \x01(\t\x12/\n\x0breceived_at\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x61\x63quired_at\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a(\n\x06Output\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\xd3\x06\n\x0bTaskSummary\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cowner_pod_id\x18\n \x01(\t\x12\x17\n\x0finitial_task_id\x18\x16 \x01(\t\x12\x1d\n\x15\x63ount_parent_task_ids\x18\x15 \x01(\x03\x12\x1f\n\x17\x63ount_data_dependencies\x18\x0b \x01(\x03\x12!\n\x19\x63ount_expected_output_ids\x18\r \x01(\x03\x12\x1a\n\x12\x63ount_retry_of_ids\x18\x0e \x01(\x03\x12;\n\x06status\x18\x04 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x16\n\x0estatus_message\x18\t \x01(\t\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csubmitted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x18\x63reation_to_end_duration\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1aprocessing_to_end_duration\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x07pod_ttl\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x08 \x01(\t\x12\x14\n\x0cpod_hostname\x18\x11 \x01(\t\x12/\n\x0breceived_at\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x61\x63quired_at\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\'\n\x16TaskOptionGenericField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\x80\x02\n\tTaskField\x12I\n\x12task_summary_field\x18\x01 \x01(\x0e\x32+.armonik.api.grpc.v1.tasks.TaskSummaryFieldH\x00\x12G\n\x11task_option_field\x18\x02 \x01(\x0e\x32*.armonik.api.grpc.v1.tasks.TaskOptionFieldH\x00\x12V\n\x19task_option_generic_field\x18\x03 \x01(\x0b\x32\x31.armonik.api.grpc.v1.tasks.TaskOptionGenericFieldH\x00\x42\x07\n\x05\x66ield\"\xdd\x05\n\x10ListTasksRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x42\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x32.armonik.api.grpc.v1.tasks.ListTasksRequest.Filter\x12>\n\x04sort\x18\x04 \x01(\x0b\x32\x30.armonik.api.grpc.v1.tasks.ListTasksRequest.Sort\x12\x13\n\x0bwith_errors\x18\x05 \x01(\x08\x1a\x8a\x03\n\x06\x46ilter\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12;\n\x06status\x18\x02 \x03(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x31\n\rcreated_after\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x63reated_before\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rstarted_after\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0estarted_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65nded_after\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65nded_before\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x81\x01\n\x04Sort\x12\x33\n\x05\x66ield\x18\x01 \x01(\x0b\x32$.armonik.api.grpc.v1.tasks.TaskField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"z\n\x11ListTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"y\n\x14ListTasksRawResponse\x12\x31\n\x05tasks\x18\x01 \x03(\x0b\x32\".armonik.api.grpc.v1.tasks.TaskRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x0eGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"C\n\x0fGetTaskResponse\x12\x30\n\x04task\x18\x01 \x01(\x0b\x32\".armonik.api.grpc.v1.tasks.TaskRaw\"&\n\x12\x43\x61ncelTasksRequest\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"L\n\x13\x43\x61ncelTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\"&\n\x13GetResultIdsRequest\x12\x0f\n\x07task_id\x18\x01 \x03(\t\"\xa1\x01\n\x14GetResultIdsResponse\x12S\n\x0ctask_results\x18\x01 \x03(\x0b\x32=.armonik.api.grpc.v1.tasks.GetResultIdsResponse.MapTaskResult\x1a\x34\n\rMapTaskResult\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x12\n\nresult_ids\x18\x02 \x03(\t\"\x1b\n\x19\x43ountTasksByStatusRequest\"N\n\x1a\x43ountTasksByStatusResponse\x12\x30\n\x06status\x18\x01 \x03(\x0b\x32 .armonik.api.grpc.v1.StatusCount\"\xca\x02\n\x12SubmitTasksRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x36\n\x0ctask_options\x18\x02 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12R\n\x0etask_creations\x18\x03 \x03(\x0b\x32:.armonik.api.grpc.v1.tasks.SubmitTasksRequest.TaskCreation\x1a\x93\x01\n\x0cTaskCreation\x12\x1c\n\x14\x65xpected_output_keys\x18\x01 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x02 \x03(\t\x12\x12\n\npayload_id\x18\x03 \x01(\t\x12\x36\n\x0ctask_options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\"\xcb\x01\n\x13SubmitTasksResponse\x12K\n\ntask_infos\x18\x01 \x03(\x0b\x32\x37.armonik.api.grpc.v1.tasks.SubmitTasksResponse.TaskInfo\x1ag\n\x08TaskInfo\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x1b\n\x13\x65xpected_output_ids\x18\x02 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x03 \x03(\t\x12\x12\n\npayload_id\x18\x04 \x01(\t*\x80\x05\n\x10TaskSummaryField\x12\"\n\x1eTASK_SUMMARY_FIELD_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTASK_SUMMARY_FIELD_TASK_ID\x10\x10\x12!\n\x1dTASK_SUMMARY_FIELD_SESSION_ID\x10\x01\x12#\n\x1fTASK_SUMMARY_FIELD_OWNER_POD_ID\x10\t\x12&\n\"TASK_SUMMARY_FIELD_INITIAL_TASK_ID\x10\n\x12\x1d\n\x19TASK_SUMMARY_FIELD_STATUS\x10\x02\x12!\n\x1dTASK_SUMMARY_FIELD_CREATED_AT\x10\x03\x12#\n\x1fTASK_SUMMARY_FIELD_SUBMITTED_AT\x10\x0b\x12!\n\x1dTASK_SUMMARY_FIELD_STARTED_AT\x10\x04\x12\x1f\n\x1bTASK_SUMMARY_FIELD_ENDED_AT\x10\x05\x12/\n+TASK_SUMMARY_FIELD_CREATION_TO_END_DURATION\x10\x06\x12\x31\n-TASK_SUMMARY_FIELD_PROCESSING_TO_END_DURATION\x10\x07\x12\x1e\n\x1aTASK_SUMMARY_FIELD_POD_TTL\x10\x0c\x12#\n\x1fTASK_SUMMARY_FIELD_POD_HOSTNAME\x10\r\x12\"\n\x1eTASK_SUMMARY_FIELD_RECEIVED_AT\x10\x0e\x12\"\n\x1eTASK_SUMMARY_FIELD_ACQUIRED_AT\x10\x0f\x12\x1c\n\x18TASK_SUMMARY_FIELD_ERROR\x10\x08*\x8d\x03\n\x0fTaskOptionField\x12!\n\x1dTASK_OPTION_FIELD_UNSPECIFIED\x10\x00\x12\"\n\x1eTASK_OPTION_FIELD_MAX_DURATION\x10\x01\x12!\n\x1dTASK_OPTION_FIELD_MAX_RETRIES\x10\x02\x12\x1e\n\x1aTASK_OPTION_FIELD_PRIORITY\x10\x03\x12\"\n\x1eTASK_OPTION_FIELD_PARTITION_ID\x10\x04\x12&\n\"TASK_OPTION_FIELD_APPLICATION_NAME\x10\x05\x12)\n%TASK_OPTION_FIELD_APPLICATION_VERSION\x10\x06\x12+\n\'TASK_OPTION_FIELD_APPLICATION_NAMESPACE\x10\x07\x12)\n%TASK_OPTION_FIELD_APPLICATION_SERVICE\x10\x08\x12!\n\x1dTASK_OPTION_FIELD_ENGINE_TYPE\x10\tB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Tasksb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Tasks'
  _TASKSUMMARYFIELD._serialized_start=4294
  _TASKSUMMARYFIELD._serialized_end=4934
  _TASKOPTIONFIELD._serialized_start=4937
  _TASKOPTIONFIELD._serialized_end=5334
  _TASKRAW._serialized_start=171
  _TASKRAW._serialized_end=1080
  _TASKRAW_OUTPUT._serialized_start=1040
  _TASKRAW_OUTPUT._serialized_end=1080
  _TASKSUMMARY._serialized_start=1083
  _TASKSUMMARY._serialized_end=1934
  _TASKOPTIONGENERICFIELD._serialized_start=1936
  _TASKOPTIONGENERICFIELD._serialized_end=1975
  _TASKFIELD._serialized_start=1978
  _TASKFIELD._serialized_end=2234
  _LISTTASKSREQUEST._serialized_start=2237
  _LISTTASKSREQUEST._serialized_end=2970
  _LISTTASKSREQUEST_FILTER._serialized_start=2444
  _LISTTASKSREQUEST_FILTER._serialized_end=2838
  _LISTTASKSREQUEST_SORT._serialized_start=2841
  _LISTTASKSREQUEST_SORT._serialized_end=2970
  _LISTTASKSRESPONSE._serialized_start=2972
  _LISTTASKSRESPONSE._serialized_end=3094
  _LISTTASKSRAWRESPONSE._serialized_start=3096
  _LISTTASKSRAWRESPONSE._serialized_end=3217
  _GETTASKREQUEST._serialized_start=3219
  _GETTASKREQUEST._serialized_end=3252
  _GETTASKRESPONSE._serialized_start=3254
  _GETTASKRESPONSE._serialized_end=3321
  _CANCELTASKSREQUEST._serialized_start=3323
  _CANCELTASKSREQUEST._serialized_end=3361
  _CANCELTASKSRESPONSE._serialized_start=3363
  _CANCELTASKSRESPONSE._serialized_end=3439
  _GETRESULTIDSREQUEST._serialized_start=3441
  _GETRESULTIDSREQUEST._serialized_end=3479
  _GETRESULTIDSRESPONSE._serialized_start=3482
  _GETRESULTIDSRESPONSE._serialized_end=3643
  _GETRESULTIDSRESPONSE_MAPTASKRESULT._serialized_start=3591
  _GETRESULTIDSRESPONSE_MAPTASKRESULT._serialized_end=3643
  _COUNTTASKSBYSTATUSREQUEST._serialized_start=3645
  _COUNTTASKSBYSTATUSREQUEST._serialized_end=3672
  _COUNTTASKSBYSTATUSRESPONSE._serialized_start=3674
  _COUNTTASKSBYSTATUSRESPONSE._serialized_end=3752
  _SUBMITTASKSREQUEST._serialized_start=3755
  _SUBMITTASKSREQUEST._serialized_end=4085
  _SUBMITTASKSREQUEST_TASKCREATION._serialized_start=3938
  _SUBMITTASKSREQUEST_TASKCREATION._serialized_end=4085
  _SUBMITTASKSRESPONSE._serialized_start=4088
  _SUBMITTASKSRESPONSE._serialized_end=4291
  _SUBMITTASKSRESPONSE_TASKINFO._serialized_start=4188
  _SUBMITTASKSRESPONSE_TASKINFO._serialized_end=4291
# @@protoc_insertion_point(module_scope)
